pub struct BackEdge {
pub target: usize,
pub chain_id: Option<usize>,
}Expand description
An edge that is not part of the spanning tree, as it would form a loop.
Fields
target: usizeThe target of the back-edge is the node that is furthest from the root of the spanning tree.
chain_id: Option<usize>The id of the chain that is created by this back-edge. It is the global index of this back-edge. Make sure to call SpanningTree::chain_decomposition first.