pub struct CanonicalForm<N, E> {
pub vertex_map: Vec<usize>,
pub orbit_generators: Vec<Vec<Vec<usize>>>,
pub orbit: Vec<usize>,
pub automorphism_group_size: Integer,
pub graph: Graph<N, E>,
}Expand description
Information about the graph and its canonical form.
Fields
vertex_map: Vec<usize>Mapping of the vertices from the input graph to the canonical graph.
orbit_generators: Vec<Vec<Vec<usize>>>Generators of the automorphism group of the graph.
orbit: Vec<usize>An orbit of the graph.
automorphism_group_size: IntegerThe size of the automorphism group of the graph, including the permutations stemming from identical edges.
graph: Graph<N, E>Auto Trait Implementations
impl<N, E> Freeze for CanonicalForm<N, E>
impl<N, E> RefUnwindSafe for CanonicalForm<N, E>where
N: RefUnwindSafe,
E: RefUnwindSafe,
impl<N, E> Send for CanonicalForm<N, E>
impl<N, E> Sync for CanonicalForm<N, E>
impl<N, E> Unpin for CanonicalForm<N, E>
impl<N, E> UnsafeUnpin for CanonicalForm<N, E>
impl<N, E> UnwindSafe for CanonicalForm<N, E>where
N: UnwindSafe,
E: UnwindSafe,